@@ -14,6 +14,7 @@ from models_cisco import IOSAaaEnableAuthenticationLine
 from models_cisco import IOSAaaCommandsAuthorizationLine
 from models_cisco import IOSAaaCommandsAccountingLine
 from models_cisco import IOSAaaExecAccountingLine
+from models_cisco import IOSAaaGroupServerLine
 from models_cisco import IOSCfgLine
 
 
@@ -38,7 +39,7 @@ from models_cisco import IOSCfgLine
 """
 
 ## Docstring props: http://stackoverflow.com/a/1523456/667301
-__version_tuple__ = (1,1,9)
+__version_tuple__ = (1,1,10)
 __version__ = '.'.join(map(str, __version_tuple__))
 __email__ = "mike /at\ pennington [dot] net"
 __author__ = "David Michael Pennington <{0}>".format(__email__)
@@ -2109,7 +2110,7 @@ def ConfigLineFactory(text="", comment_delimiter="!", syntax='ios'):
     classes = [IOSIntfLine, IOSRouteLine, IOSAccessLine, 
         IOSAaaLoginAuthenticationLine, IOSAaaEnableAuthenticationLine,
         IOSAaaCommandsAuthorizationLine, IOSAaaCommandsAccountingLine,
-        IOSAaaExecAccountingLine,
+        IOSAaaExecAccountingLine, IOSAaaGroupServerLine,
         IOSHostnameLine, IOSIntfGlobal, IOSCfgLine]  # This is simple
     for cls in classes:
         if cls.is_object_for(text):
